@@ -1,10 +1,10 @@
 from typing import List
-from pydantic import BaseModel
+from pydantic import BaseModel, Field
 from beanie import PydanticObjectId
 
 
 class Entity(BaseModel):
-    id: PydanticObjectId
+    id: PydanticObjectId = Field(default_factory=PydanticObjectId, alias='_id')
 
     class Config:
         allow_population_by_field_name = True
